@@ -1,4 +1,4 @@
-JENKINS_VIEW_NAME = 'БЦ БО Бухгалтерия и ЗиК'
+JENKINS_FOLDER_CLASS = 'com.cloudbees.hudson.plugins.folder.Folder'
 
 JENKINS_JOB_DISABLED_COLOR = 'disabled'
 JENKINS_JOB_RED_COLOR = 'red'
