@@ -240,6 +240,7 @@ class ProjectPluginEnum(Enum):
     UDMURTIA_UFK = 'udmurtia_ufk'
     URM_KRISTA = 'urm_krista'
     PERIOD_CLOSING_EXT = 'period_closing_ext'
+    IMPORT_PP_WEB = 'import_pp_web'
 
     # Плигины ЗиК
     SALARY = 'salary'
@@ -479,6 +480,7 @@ class ProjectPluginEnum(Enum):
                     cls.OPERATIONS_JOURNAL_04_ACCOUNTS_ANALYTICS,
                     cls.UDMURTIA_UFK,
                     cls.PERIOD_CLOSING_EXT,
+                    cls.IMPORT_PP_WEB,
                 )
             )
 
@@ -597,6 +599,9 @@ class ProjectPluginEnum(Enum):
             cls.IMPORT_PP_TXT: (
                 cls.ACCOUNTING,
             ),
+            cls.IMPORT_PP_WEB: (
+                cls.ACCOUNTING,
+            ),
             cls.IMPORT_SUFD_FO: (
                 cls.ACCOUNTING,
             ),
